import { select, 
        csv,
        scaleLinear,
        scaleTime, 
        extent, 
        axisLeft,
        axisBottom,
        area,
        axisTop,
        curveBasis,
        max,
        format
} from "d3";

const svg 		= d3.select('svg');

const height 	= +svg.attr('height');
const width 	= +svg.attr('width');


const render = data => {
  const title = 'Word Population'
  const xValue = d => d.year;
  const xAxisLabel =  'Year'
  const yValue = d => d.population;
  const yAxisLabel =  'Population'
  const circleRadius = 6;
  const margin = {top: 60, left: 150, right: 40, bottom: 120}
  const innerWidth = width - (margin.right+margin.left)
  const innerHeight = height - (margin.top+margin.bottom)
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth]);
  
    
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0])
  	.nice();
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  
  const xAxis = axisBottom(xScale)
  	.ticks(6)
  	.tickSize(-innerHeight + 5)
  	.tickPadding(20);
  
  const xAxisTickFormat = number => 
  	format('.1s')(number)
  		.replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(xAxisTickFormat);
  
  const yAxisG = g.append('g')
    	.call(yAxis);
  	yAxisG.selectAll('.domain').remove();

  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -90)
  	.attr('x', -innerHeight/2)
    .attr('fill', 'black')
  	.text(yAxisLabel)
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle');
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`)
  	
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 80)
  	.attr('x', innerWidth/2)
    .attr('fill', 'black')
  	.text(xAxisLabel);
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(data));
  
  svg.append('text')
  	.attr('class', 'title')
  	.attr('x', width/2)
  	.attr('y', 50)
  	.text(title)
};

	

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv').then(data => {
	data.forEach(d => {
  	d.year = new Date(d.year);
    d.population = d.population;
    
  });
  render(data);
})
